Class: Google::Apis::PrivatecaV1beta1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1beta1/classes.rb,
lib/google/apis/privateca_v1beta1/representations.rb,
lib/google/apis/privateca_v1beta1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



372
373
374
# File 'lib/google/apis/privateca_v1beta1/classes.rb', line 372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/privateca_v1beta1/classes.rb', line 347

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


353
354
355
# File 'lib/google/apis/privateca_v1beta1/classes.rb', line 353

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


358
359
360
# File 'lib/google/apis/privateca_v1beta1/classes.rb', line 358

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


364
365
366
# File 'lib/google/apis/privateca_v1beta1/classes.rb', line 364

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


370
371
372
# File 'lib/google/apis/privateca_v1beta1/classes.rb', line 370

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



377
378
379
380
381
382
383
# File 'lib/google/apis/privateca_v1beta1/classes.rb', line 377

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end