Class: Google::Apis::PrivatecaV1beta1::CertificateAuthorityServiceService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::PrivatecaV1beta1::CertificateAuthorityServiceService
- Defined in:
- lib/google/apis/privateca_v1beta1/service.rb
Overview
Certificate Authority API
The Certificate Authority Service API is a highly-available, scalable service that enables you to simplify and automate the management of private certificate authorities (CAs) while staying in control of your private keys.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://privateca.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Location
Gets information about a location.
-
#get_project_location_certificate_authority_certificate_revocation_list_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Gets the access control policy for a resource.
-
#get_project_location_certificate_authority_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_reusable_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Gets the access control policy for a resource.
-
#initialize ⇒ CertificateAuthorityServiceService
constructor
A new instance of CertificateAuthorityServiceService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#set_certificate_authority_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Sets the access control policy on the specified resource.
-
#set_certificate_revocation_list_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Sets the access control policy on the specified resource.
-
#set_reusable_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Sets the access control policy on the specified resource.
-
#test_certificate_authority_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_certificate_revocation_list_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_reusable_config_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ CertificateAuthorityServiceService
Returns a new instance of CertificateAuthorityServiceService.
49 50 51 52 53 54 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-privateca_v1beta1', client_version: Google::Apis::PrivatecaV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 412 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:cancel', ) command.request_representation = Google::Apis::PrivatecaV1beta1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::PrivatecaV1beta1::Empty::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
447 448 449 450 451 452 453 454 455 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 447 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::PrivatecaV1beta1::Empty::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Location
Gets information about a location.
76 77 78 79 80 81 82 83 84 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 76 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::PrivatecaV1beta1::Location::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_certificate_authority_certificate_revocation_list_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
297 298 299 300 301 302 303 304 305 306 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 297 def (resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::PrivatecaV1beta1::Policy::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_certificate_authority_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 176 def (resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::PrivatecaV1beta1::Policy::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
478 479 480 481 482 483 484 485 486 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 478 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::PrivatecaV1beta1::Operation::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_reusable_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
571 572 573 574 575 576 577 578 579 580 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 571 def get_project_location_reusable_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::PrivatecaV1beta1::Policy::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 523 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::PrivatecaV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::PrivatecaV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 128 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::PrivatecaV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::PrivatecaV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_certificate_authority_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 212 def (resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::PrivatecaV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::PrivatecaV1beta1::Policy::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_certificate_revocation_list_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 333 def set_certificate_revocation_list_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::PrivatecaV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::PrivatecaV1beta1::Policy::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_reusable_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 607 def set_reusable_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::PrivatecaV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::PrivatecaV1beta1::Policy::Representation command.response_class = Google::Apis::PrivatecaV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_certificate_authority_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 251 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::PrivatecaV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_certificate_revocation_list_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 372 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::PrivatecaV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_reusable_config_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
646 647 648 649 650 651 652 653 654 655 656 |
# File 'lib/google/apis/privateca_v1beta1/service.rb', line 646 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::PrivatecaV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::PrivatecaV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |